@@ -11,6 +11,7 @@ from typing import (
     Union,
 )
 
+from asyncz.contrib.esmerald.scheduler import EsmeraldScheduler
 from esmerald.conf import settings
 from esmerald.config import CORSConfig, CSRFConfig, SessionConfig, TemplateConfig
 from esmerald.config.openapi import OpenAPIConfig
@@ -31,10 +32,9 @@ from esmerald.middleware.exceptions import (
 from esmerald.middleware.sessions import SessionMiddleware
 from esmerald.middleware.trustedhost import TrustedHostMiddleware
 from esmerald.permissions.types import Permission
+from esmerald.protocols.template import TemplateEngineProtocol
 from esmerald.routing import gateways
 from esmerald.routing.router import HTTPHandler, Include, Router, WebSocketHandler
-from esmerald.schedulers.apscheduler.handler import Scheduler
-from esmerald.template.base import TemplateEngineProtocol
 from esmerald.types import (
     APIGateHandler,
     ASGIApp,
@@ -68,7 +68,7 @@ class Esmerald(Starlette):
 
     __slots__ = (
         "title",
-        "name",
+        "app_name",
         "description",
         "version",
         "contact",
@@ -92,11 +92,13 @@ class Esmerald(Starlette):
         "response_cookies",
         "response_headers",
         "scheduler_class",
+        "scheduler",
         "tags",
         "root_path",
         "deprecated",
         "security",
         "include_in_schema",
+        "redirect_slashes",
     )
 
     def __init__(
@@ -106,7 +108,7 @@ class Esmerald(Starlette):
         title: Optional[str] = settings.title,
         version: Optional[str] = settings.version,
         summary: Optional[str] = settings.summary,
-        name: Optional[str] = settings.app_name,
+        app_name: Optional[str] = settings.app_name,
         description: Optional[str] = settings.description,
         contact: Optional[Dict[str, Union[str, Any]]] = settings.contact,
         terms_of_service: Optional[str] = settings.terms_of_service,
@@ -145,6 +147,7 @@ class Esmerald(Starlette):
         include_in_schema: bool = settings.include_in_schema,
         deprecated: Optional[bool] = None,
         enable_openapi: bool = settings.enable_openapi,
+        redirect_slashes: bool = settings.redirect_slashes,
     ) -> None:
 
         assert lifespan is None or (
@@ -156,7 +159,7 @@ class Esmerald(Starlette):
 
         self._debug = debug
         self.title = title
-        self.name = name
+        self.name = app_name
         self.description = description
         self.version = version
         self.summary = summary
@@ -196,6 +199,7 @@ class Esmerald(Starlette):
         self.on_startup = on_startup
         self.security = security
         self.enable_openapi = enable_openapi
+        self.redirect_slashes = redirect_slashes
 
         self.router: "Router" = Router(
             on_shutdown=on_shutdown,
@@ -205,6 +209,7 @@ class Esmerald(Starlette):
             lifespan=lifespan,
             deprecated=deprecated,
             security=security,
+            redirect_slashes=self.redirect_slashes,
         )
 
         self.exception_handlers = {} if exception_handlers is None else dict(exception_handlers)
@@ -225,7 +230,7 @@ class Esmerald(Starlette):
                 self.router.routes.append(static_route)
 
         if self.enable_scheduler:
-            self.scheduler = Scheduler(
+            self.scheduler = EsmeraldScheduler(
                 app=self,
                 scheduler_class=self.scheduler_class,
                 tasks=self.scheduler_tasks,
