@@ -1,9 +1,8 @@
 from typing import List, Type, Union
 
-from pydantic import BaseConfig, BaseModel, DirectoryPath
-
-from esmerald.template.base import TemplateEngineProtocol
+from esmerald.protocols.template import TemplateEngineProtocol
 from esmerald.template.jinja import JinjaTemplateEngine
+from pydantic import BaseConfig, BaseModel, DirectoryPath
 
 
 class TemplateConfig(BaseModel):
